@@ -144,6 +144,7 @@ SplitType = Literal["TEST", "TRAIN"]
 SyntaxLanguageCodeType = Literal["de", "en", "es", "fr", "it", "pt"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -176,6 +177,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
